@@ -27,8 +27,14 @@
 #include <gdk/gdkx.h>
 #include <gio/gio.h>
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+#include <libdbusmenu-gtk3/menuitem.h>
+#include <libdbusmenu-gtk3/parser.h>
+#else
 #include <libdbusmenu-gtk/menuitem.h>
 #include <libdbusmenu-gtk/parser.h>
+#endif
+
 #include <libdbusmenu-glib/menuitem.h>
 #include <libdbusmenu-glib/server.h>
 
@@ -796,14 +802,12 @@ app_menu_bridge_insert (UbuntuMenuProxy *proxy,
                         guint            position)
 {
   AppMenuBridge        *bridge;
-  AppMenuBridgePrivate *priv;
   GtkWidget            *toplevel = NULL;
 
   if (GTK_IS_TEAROFF_MENU_ITEM (child))
     return;
 
   bridge = APP_MENU_BRIDGE (proxy);
-  priv = bridge->priv;
 
   toplevel = gtk_widget_get_toplevel (parent);
 
@@ -856,6 +860,7 @@ app_menu_bridge_insert (UbuntuMenuProxy *proxy,
               dbusmenu_menuitem_child_add_position (mi,
                                                     child_dmi,
                                                     position);
+              g_object_unref (child_dmi);
               return;
             }
 
@@ -890,7 +895,8 @@ app_menu_bridge_show_local (UbuntuMenuProxy *proxy)
   return local;
 }
 
-/* crude blacklist to avoid patching innoncent apps */
+/* Crude blacklist to avoid patching innocent apps */
+/* Use xprop | grep CLASS to find the name to use */
 static gboolean
 app_menu_brige_shouldnt_load (void)
 {
@@ -903,6 +909,9 @@ app_menu_brige_shouldnt_load (void)
       || (g_strcmp0 (prg, "firefox-bin") == 0)
       || (g_strcmp0 (prg, "thunderbird-bin") == 0)
       || (g_strcmp0 (prg, "Eclipse") == 0)
+      || (g_strcmp0 (prg, "emacs") == 0)
+      || (g_strcmp0 (prg, "emacs23") == 0)
+      || (g_strcmp0 (prg, "emacs23-lucid") == 0)
       || (g_strcmp0 (prg, "gnome-panel") == 0))
     {
       return TRUE;
